/**
 * @description 事件委托:只能一级标签，点击多级嵌套标签，不执行回调
 * @param {*} el 事件委托的元素
 * @param {*} type  事件类型
 * @param {*} selector 选择器
 * @param {*} fn 回调函数
 * @example
 *
 */
export function eventDelegaOne(el, type, selector, fn) {
  // 如果el不是传的字符串，返回
  if (typeof el !== "string") return;
  // 获取元素
  let element = document.querySelector(el);
  // 监听事件
  element.addEventListener(type, function (e) {
    // 获取点击的元素
    let target = e.target;
    // 如果元素被指定的选择器字符串选择
    if (target.matches(selector)) {
      fn.call(target, e);
    }
  });
}

/**
 * @description 事件委托，解决多级嵌套文本，点击获取不到的问题
 * @param {*} el 事件委托的元素
 * @param {*} type  事件类型
 * @param {*} selector 选择器
 * @param {*} fn 回调函数
 */
export function eventDelega(el, type, selector, fn) {
  // 如果el不是传的字符串，返回
  if (typeof el !== "string") return;
  // 获取元素
  let element = document.querySelector(el);
  // 监听事件
  element.addEventListener(type, function (e) {
    // 获取点击的元素
    let target = e.target;
    // 当点击的元素 ！= 传入的元素
    while (target != element) {
      // matches 大部分浏览器支持，ie9,edge15 都支持
      // 如果元素被指定的选择器字符串选择
      if (target.matches(selector)) {
        return fn.call(target, e);
      }
      // 当前对象=当前对象的父级元素，一层一层向上查找selector
      target = target.parentNode;
    }
  });
}
